@@ -5,7 +5,7 @@ import subprocess
 import sys
 from argparse import Namespace
 from functools import lru_cache
-from typing import Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 from packaging.version import Version
 
@@ -46,6 +46,7 @@ BASE_KINDS = [
         "text/jinja2": "**/*.j2"
     },  # jinja2 templates are not always parsable as something else
     {"text/jinja2": "**/*.j2.*"},
+    {"text": "**/templates/**/*.*"},  # templates are likely not validable
     {"text/json": "**/*.json"},  # standardized
     {"text/markdown": "**/*.md"},  # https://tools.ietf.org/html/rfc7763
     {"text/rst": "**/*.rst"},  # https://en.wikipedia.org/wiki/ReStructuredText
@@ -58,6 +59,7 @@ BASE_KINDS = [
 
 
 options = Namespace(
+    cache_dir=".cache",
     colored=True,
     configured=False,
     cwd=".",
@@ -78,11 +80,13 @@ options = Namespace(
     mock_modules=[],
     mock_roles=[],
     loop_var_prefix=None,
+    var_naming_pattern=None,
     offline=False,
     project_dir=".",  # default should be valid folder (do not use None here)
     extra_vars=None,
     enable_list=[],
     skip_action_validation=True,
+    rules=dict(),  # Placeholder to set and keep configurations for each rule.
 )
 
 # Used to store detected tag deprecations
@@ -92,6 +96,14 @@ used_old_tags: Dict[str, str] = {}
 collection_list: List[str] = []
 
 
+def get_rule_config(rule_id: str) -> Dict[str, Any]:
+    """Get configurations for the rule ``rule_id``."""
+    rule_config = options.rules.get(rule_id, dict())
+    if not isinstance(rule_config, dict):
+        raise RuntimeError("Invalid rule config for %s: %s" % (rule_id, rule_config))
+    return rule_config
+
+
 @lru_cache()
 def ansible_collections_path() -> str:
     """Return collection path variable for current version of Ansible."""
@@ -108,12 +120,14 @@ def ansible_collections_path() -> str:
 
 def parse_ansible_version(stdout: str) -> Tuple[str, Optional[str]]:
     """Parse output of 'ansible --version'."""
+    # Ansible can produce extra output before displaying version in debug mode.
+
     # ansible-core 2.11+: 'ansible [core 2.11.3]'
-    match = re.match(r"^ansible \[(?:core|base) ([^\]]+)\]", stdout)
+    match = re.search(r"^ansible \[(?:core|base) ([^\]]+)\]", stdout, re.MULTILINE)
     if match:
         return match.group(1), None
     # ansible-base 2.10 and Ansible 2.9: 'ansible 2.x.y'
-    match = re.match(r"^ansible ([^\s]+)", stdout)
+    match = re.search(r"^ansible ([^\s]+)", stdout, re.MULTILINE)
     if match:
         return match.group(1), None
     return "", "FATAL: Unable parse ansible cli version: %s" % stdout
