@@ -11,7 +11,9 @@ from pathlib import Path
 from tempfile import NamedTemporaryFile
 from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, Set, Union
 
+# import wcmatch
 import wcmatch.pathlib
+from wcmatch.wcmatch import RECURSIVE, WcMatch
 
 from ansiblelint.config import BASE_KINDS, options
 from ansiblelint.constants import FileType
@@ -67,7 +69,7 @@ def expand_paths_vars(paths: List[str]) -> List[str]:
     return paths
 
 
-def kind_from_path(path: Path, base=False) -> str:
+def kind_from_path(path: Path, base: bool = False) -> FileType:
     """Determine the file kind based on its name.
 
     When called with base=True, it will return the base file type instead
@@ -87,7 +89,7 @@ def kind_from_path(path: Path, base=False) -> str:
                     | wcmatch.pathlib.DOTGLOB
                 ),
             ):
-                return str(k)
+                return str(k)  # type: ignore
 
     if base:
         # Unknown base file type is default
@@ -120,6 +122,7 @@ class Lintable:
         # Filename is effective file on disk, for stdin is a namedtempfile
         self.filename: str = str(name)
         self.dir: str = ""
+        self.kind: Optional[FileType] = None
 
         if isinstance(name, str):
             self.name = normpath(name)
@@ -140,6 +143,7 @@ class Lintable:
                 self.role = role.name
 
         if str(self.path) in ['/dev/stdin', '-']:
+            # pylint: disable=consider-using-with
             self.file = NamedTemporaryFile(mode="w+", suffix="playbook.yml")
             self.filename = self.file.name
             self._content = sys.stdin.read()
@@ -199,22 +203,21 @@ class Lintable:
         return f"{self.name} ({self.kind})"
 
 
-def get_yaml_files(options: Namespace) -> Dict[str, Any]:
-    """Find all yaml files."""
+def discover_lintables(options: Namespace) -> Dict[str, Any]:
+    """Find all files that we know how to lint."""
     # git is preferred as it also considers .gitignore
     git_command = ['git', 'ls-files', '-z']
-    _logger.info("Discovering files to lint: %s", ' '.join(git_command))
-
     out = None
 
     try:
         out = subprocess.check_output(
             git_command, stderr=subprocess.STDOUT, universal_newlines=True
         ).split("\x00")[:-1]
+        _logger.info("Discovered files to lint using: %s", ' '.join(git_command))
     except subprocess.CalledProcessError as exc:
         if not (exc.returncode == 128 and 'fatal: not a git repository' in exc.output):
             _logger.warning(
-                "Failed to discover yaml files to lint using git: %s",
+                "Failed to discover lintable files using git: %s",
                 exc.output.rstrip('\n'),
             )
     except FileNotFoundError as exc:
@@ -222,12 +225,11 @@ def get_yaml_files(options: Namespace) -> Dict[str, Any]:
             _logger.warning("Failed to locate command: %s", exc)
 
     if out is None:
-        out = [
-            os.path.join(root, name)
-            for root, dirs, files in os.walk('.')
-            for name in files
-            if name.endswith('.yaml') or name.endswith('.yml')
-        ]
+        exclude_pattern = "|".join(str(x) for x in options.exclude_paths)
+        _logger.info("Looking up for files, excluding %s ...", exclude_pattern)
+        out = WcMatch(
+            '.', exclude_pattern=exclude_pattern, flags=RECURSIVE, limit=256
+        ).match()
 
     return OrderedDict.fromkeys(sorted(out))
 
@@ -263,7 +265,7 @@ def expand_dirs_in_lintables(lintables: Set[Lintable]) -> None:
 
     if should_expand:
         # this relies on git and we do not want to call unless needed
-        all_files = get_yaml_files(options)
+        all_files = discover_lintables(options)
 
         for item in copy.copy(lintables):
             if item.path.is_dir():
