@@ -1,10 +1,15 @@
 # Copyright (c) 2016, Tsukinowa Inc. <info@tsukinowa.jp>
 # Copyright (c) 2018, Ansible Project
 
-from typing import Any, Dict, Union
+from typing import TYPE_CHECKING, Any, Dict, Union
 
 from ansiblelint.rules import AnsibleLintRule
 
+if TYPE_CHECKING:
+    from typing import Optional
+
+    from ansiblelint.file_utils import Lintable
+
 
 class RoleRelativePath(AnsibleLintRule):
     id = 'no-relative-paths'
@@ -23,7 +28,9 @@ class RoleRelativePath(AnsibleLintRule):
         'win_template': 'win_templates',
     }
 
-    def matchtask(self, task: Dict[str, Any]) -> Union[bool, str]:
+    def matchtask(
+        self, task: Dict[str, Any], file: 'Optional[Lintable]' = None
+    ) -> Union[bool, str]:
         module = task['action']['__ansible_module__']
         if module not in self._module_to_path_folder:
             return False
